summaryrefslogtreecommitdiffstats
path: root/kcontrol/input/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/input/main.cpp')
-rw-r--r--kcontrol/input/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kcontrol/input/main.cpp b/kcontrol/input/main.cpp
index 0ab009ec9..38bded500 100644
--- a/kcontrol/input/main.cpp
+++ b/kcontrol/input/main.cpp
@@ -27,7 +27,7 @@
#include <klocale.h>
#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
#include <dcopref.h>
#include <tqfile.h>
@@ -80,13 +80,13 @@ extern "C"
XDefineCursor(tqt_xdisplay(), tqt_xrootwin(), handle);
XFreeCursor(tqt_xdisplay(), handle); // Don't leak the cursor
// Tell klauncher to set the XCURSOR_THEME and XCURSOR_SIZE environment
// variables when launching applications.
- DCOPRef klauncher("klauncher");
+ DCOPRef tdelauncher("tdelauncher");
if( !theme.isEmpty())
- klauncher.send("setLaunchEnv", TQCString("XCURSOR_THEME"), theme);
+ tdelauncher.send("setLaunchEnv", TQCString("XCURSOR_THEME"), theme);
if( !size.isEmpty())
- klauncher.send("setLaunchEnv", TQCString("XCURSOR_SIZE"), size);
+ tdelauncher.send("setLaunchEnv", TQCString("XCURSOR_SIZE"), size);
#endif
delete config;
@@ -80,13 +80,13 @@ extern "C"
XDefineCursor(tqt_xdisplay(), tqt_xrootwin(), handle);
XFreeCursor(tqt_xdisplay(), handle); // Don't leak the cursor
- // Tell klauncher to set the XCURSOR_THEME and XCURSOR_SIZE environment
+ // Tell tdelauncher to set the XCURSOR_THEME and XCURSOR_SIZE environment
// variables when launching applications.